Console class

Handles the printing to the terminal

Constructors

Console()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

logError(String message) → void
Logs a text in red
logInfo(String message) → void
Logs a text in bold white
logSuccess(String message) → void
Logs a text in green
logWarning(String message) → void
Logs a text in yellow