ProcessHelper class

The helper class for running commands

Constructors

ProcessHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

runCommand({required String executable, required List<String> arguments, bool stdoutWrite = false, String? logFilePath, String? startMessage, String? successMessage, String? errorMessage, bool exitIfError = true, List<String>? redactions, bool? clearStartMessage}) Future<(int, List<String>)>
Runs a given command and handles the logging
runCommandUsingConfig({required String executable, required List<String> arguments, required BPConfig config, String? startMessage, String? successMessage, String? errorMessage, bool exitIfError = true, List<String>? redactions, bool? clearStartMessage}) Future<(int, List<String>)>
Calls the runCommand function of this class under the hood but instead of taking all the arguments, it uses the user provided config to pass the necessary arguments
splitCommand(String command) List<String>
Splitting the command while respecting the quoted strings